==> zio-aws-alexaforbusiness_3-5.17.104.2-sources.jar: zio/aws/alexaforbusiness/model/UpdateRequireCheckIn.scala <==
package zio.aws.alexaforbusiness.model
import java.lang.Integer
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.Minutes
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateRequireCheckIn(
    releaseAfterMinutes: Option[Minutes] = None,
    enabled: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn = {
    import UpdateRequireCheckIn.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
      .builder()
      .optionallyWith(
        releaseAfterMinutes.map(value => Minutes.unwrap(value): Integer)
      )(_.releaseAfterMinutes)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.ReadOnly =
    zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.wrap(buildAwsValue())
}
object UpdateRequireCheckIn {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.UpdateRequireCheckIn =
      zio.aws.alexaforbusiness.model.UpdateRequireCheckIn(
        releaseAfterMinutes.map(value => value),
        enabled.map(value => value)
      )
    def releaseAfterMinutes: Option[Minutes]
    def enabled: Option[Boolean]
    def getReleaseAfterMinutes: ZIO[Any, AwsError, Minutes] =
      AwsError.unwrapOptionField("releaseAfterMinutes", releaseAfterMinutes)
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
  ) extends zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.ReadOnly {
    override val releaseAfterMinutes: Option[Minutes] = scala
      .Option(impl.releaseAfterMinutes())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Minutes(value))
    override val enabled: Option[Boolean] =
      scala.Option(impl.enabled()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
  ): zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-alexaforbusiness_3-5.17.211.1-sources.jar: zio/aws/alexaforbusiness/model/UpdateRequireCheckIn.scala <==
package zio.aws.alexaforbusiness.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.alexaforbusiness.model.primitives.Minutes
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class UpdateRequireCheckIn(
    releaseAfterMinutes: Optional[Minutes] = Optional.Absent,
    enabled: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn = {
    import UpdateRequireCheckIn.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
      .builder()
      .optionallyWith(
        releaseAfterMinutes.map(value => Minutes.unwrap(value): Integer)
      )(_.releaseAfterMinutes)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.ReadOnly =
    zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.wrap(buildAwsValue())
}
object UpdateRequireCheckIn {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.UpdateRequireCheckIn =
      zio.aws.alexaforbusiness.model.UpdateRequireCheckIn(
        releaseAfterMinutes.map(value => value),
        enabled.map(value => value)
      )
    def releaseAfterMinutes: Optional[Minutes]
    def enabled: Optional[Boolean]
    def getReleaseAfterMinutes: ZIO[Any, AwsError, Minutes] =
      AwsError.unwrapOptionField("releaseAfterMinutes", releaseAfterMinutes)
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
  ) extends zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.ReadOnly {
    override val releaseAfterMinutes: Optional[Minutes] = zio.aws.core.internal
      .optionalFromNullable(impl.releaseAfterMinutes())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Minutes(value))
    override val enabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateRequireCheckIn
  ): zio.aws.alexaforbusiness.model.UpdateRequireCheckIn.ReadOnly = new Wrapper(
    impl
  )
}
